---
name: Documentation Enhancement
about: Suggest improvements to Padricks Documentation
title: ''
labels: documentation
assignees: ''

---

**Topic**
Describe here, what is unclear or left out in Padrick's current documentation

**How should the documentation be improved?**
Describe here how the documentation should be improved. Pull requests with the changes are even more welcome :-)
